#
# spec file for package liblangtag
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define libname liblangtag1
Name:           liblangtag
Version:        0.6.7
Release:        1.1
Summary:        An interface library to access tags for identifying languages
License:        LGPL-3.0-or-later OR MPL-2.0
Group:          Productivity/Publishing/Word
URL:            https://bitbucket.org/tagoh/liblangtag
Source0:        https://bitbucket.org/tagoh/%{name}/downloads/%{name}-%{version}.tar.bz2
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxml-2.0)

%description
%{name} is an interface library to access tags for identifying
languages.

Features:
* several subtag registry database supports:
  - language
  - extlang
  - script
  - region
  - variant
  - extension
  - grandfathered
  - redundant
* handling of the language tags
  - parser
  - matching
  - canonicalizing

%package -n %{libname}
Summary:        C++ library for identification of the language from tags
Group:          System/Libraries

%description -n %{libname}
%{name} is an interface library to access tags for identifying
languages.

Features:
* several subtag registry database supports:
  - language
  - extlang
  - script
  - region
  - variant
  - extension
  - grandfathered
  - redundant
* handling of the language tags
  - parser
  - matching
  - canonicalizing

%package devel
Summary:        Files for Developing with %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(glib-2.0)

%description devel
%{name} is an interface library to access tags for identifying
languages.

This package contains the %{name} development files.

%package doc
Summary:        Documentation of %{name} API
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
export CFLAGS=-std=gnu99
%configure \
	--disable-silent-rules \
	--disable-static \
	--enable-test \
	--disable-introspection \
	--docdir=%{_docdir}/%{name}
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%dir %{_libdir}/%{name}/
%dir %{_datadir}/%{name}/
%{_libdir}/*.so.1*
%{_libdir}/%{name}/*
%{_datadir}/%{name}/*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_includedir}/%{name}*

%files doc
%dir %{_datadir}/gtk-doc/html/
%{_datadir}/gtk-doc/html/%{name}

%changelog
* Thu Feb 15 2024 pgajdos@suse.com
- version update to 0.6.7
  0.6.6 -> 0.6.7
  =================
  Akira TAGOH (1):
    Add missing header
  0.6.5 -> 0.6.6
  =================
  Akira TAGOH (2):
    Do not use variable array of bash-ism.
    Fix more compile warnings
- deleted patches
  - 0001-ro-MD-ro-to-get-make-check-to-succeed.patch (upstreamed)
* Wed Aug  2 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Fix check-tag test failled
  [0001-ro-MD-ro-to-get-make-check-to-succeed.patch]
- Version update to 0.6.4
  Replace the word of 'master' to 'primary'
  trivial update
  Stop shipping ChangeLog
  Fix build issue for docs
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Specify -std=gnu99 in order to be able to build with older
  compilers
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6.3:
  Fix possible null argument for %%s directive
  Add ax_check_enable_debug.m4 to satisfy requirement
  enable round tripping ca@valencia locale string back to ca@valencia again
  coverity: fix memory leaks on failure
  coverity: fix more memory leaks
* Wed May 30 2018 tchvatal@suse.com
- Version update to 0.6.2:
  * use standard function
  * fix leak in test
* Mon Sep 26 2016 tchvatal@suse.com
- Version update to 0.6.1:
  * Initialize databases just once.
  * Support BCP47-like locale representation
  * Use deprecation macros
  * Add a lookup table to catch up a script/language from language/script
  * Update to add more files into .gitignore
  * Fix the behavior on lt_tag_transform() according to tr#35
  * Fix a segfault if no territory or script is given to lt_tag_convert_from_locale_string()
  * Add missing header file
  * Add lt_db_set_val() to change the place of database
  * Fix memory leaks
  * missing gobject function for lt_relation_db thing
  * Support the language alias for the canonicalization
  * Fix lt_trie_keys() not working
  * Fix OOM handling
  * Improve the bootup time
  * Add docs
  * Update the library versioning
* Mon Dec 21 2015 tchvatal@suse.com
- Version bump to 0.5.8:
  * Fix the build requirement in pkgconfig file
  * Make some header files public (fixes: issue#14)
  * Fix test fail on SunOS
  * Fix unknown node issue
* Tue Jul 14 2015 tchvatal@suse.com
- Version bump to 0.5.7:
  * Tons of fixes between 0.5.4 and this release. Read NEWS file
* Wed Jun 25 2014 tchvatal@suse.com
- Version bump to 0.5.4:
  * Various small items detailed in NEWS file
  * Removed language stubtag registry
* Tue May 20 2014 tchvatal@suse.com
- Add condition around noarch doc subpkg to work with SLE11
* Mon May 12 2014 tchvatal@suse.com
- Version bump to 0.5.3:
  * Various small fixes detailed in NEWS file
* Mon Sep 23 2013 tchvatal@suse.com
- Version bump to 0.5.2
  * Various autootool fixes
  * coverity fixes
  * For more read up NEWS file
* Wed May  1 2013 tchvatal@suse.com
- Version bump to 0.5.1
  * resolves abi compatibility issues.
* Sat Apr 27 2013 tchvatal@suse.com
- Version bump to 0.5
  * Enhancements:
  * Iterator support
  * Add lt_tag_convert_from_locale_string()
  * Bug Fixes:
  * Fix wrong traversal on keys
  * Fix xml parser for tags in range
  * Improve portability
  * Fix broken lt_tag_transform()
  * Fix the build issue when builddir != srcdir
  * Fix broken lt_tag_convert_from_locale()
  * Fix memory leaks
  * Fix linker issue
  * Use secure_getenv if available
  * more
- Remove upstreamed patches.
* Sat Apr 20 2013 tchvatal@suse.com
- Use full download url.
- Apply patches from git to fix few build issues.
* Wed Nov 14 2012 tchvatal@suse.com
- Fix Requires to demand glib2-devel not gtk1 variant
  (thanks coolo)
  * Fix copy&pasto in one summary.
* Tue Nov 13 2012 tchvatal@suse.com
- Use both lpgl and mpl licenses.
  * thanks to babelworx for the hint (merge request fails to
    complete so doing it myself).
* Fri Nov  9 2012 tchvatal@suse.com
- Fix desc not to contain mention of libexttextcat.
* Wed Nov  7 2012 tchvatal@suse.com
- Add missing directory to the list.
* Tue Nov  6 2012 tchvatal@suse.com
- Initial package. Version 0.4.0.
